@@ -1,7 +1,7 @@
 """
 Type annotations for codeguru-reviewer service client paginators.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguru_reviewer/paginators.html)
+[Open documentation](./paginators.md)
 
 Usage::
 
@@ -22,18 +22,15 @@ from typing import Iterator, List
 
 from botocore.paginate import Paginator as Boto3Paginator
 
-from mypy_boto3_codeguru_reviewer.literals import ProviderType, RepositoryAssociationState
-from mypy_boto3_codeguru_reviewer.type_defs import (
-    ListRepositoryAssociationsResponseTypeDef,
-    PaginatorConfigTypeDef,
-)
+from .literals import ProviderType, RepositoryAssociationState
+from .type_defs import ListRepositoryAssociationsResponseTypeDef, PaginatorConfigTypeDef
 
 __all__ = ("ListRepositoryAssociationsPaginator",)
 
 
 class ListRepositoryAssociationsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.68/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Paginator.ListRepositoryAssociations)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguru_reviewer/paginators.html#listrepositoryassociationspaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Paginator.ListRepositoryAssociations)[Show boto3-stubs documentation](./paginators.md#listrepositoryassociationspaginator)
     """
 
     def paginate(
@@ -45,6 +42,6 @@ class ListRepositoryAssociationsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListRepositoryAssociationsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.68/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Paginator.ListRepositoryAssociations.paginate)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguru_reviewer/paginators.html#listrepositoryassociationspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Paginator.ListRepositoryAssociations.paginate)
+        [Show boto3-stubs documentation](./paginators.md#listrepositoryassociationspaginator)
         """
